<?php
$lang['0_product'] = 'Produkt';
$lang['1_service'] = 'Service';
$lang['2_discount'] = 'Rabat';
$lang['3_shipping'] = 'Wysyłka';
$lang['4_tax'] = 'Podatek';
$lang['addedit_billingform_template'] = 'Dodaj/Edytuj szablon rachunku';
$lang['addedit_completion_template'] = 'Dodaj/Edytuj Completion Template';
$lang['addedit_confirmorder_template'] = 'Dodaj/Edytuj szablon potwierdzenia zam&oacute;wienia';
$lang['addedit_gateway_complete_template'] = 'Dodaj/Edytuj Gateway Complete Template';
$lang['addedit_invoice_template'] = 'Dodaj/Edytuj szablon faktury';
$lang['addedit_paymentform_template'] = 'Dodaj/Edytuj szablon płatności';
$lang['address1'] = 'Adres Linia 1';
$lang['address2'] = 'Adres Linia 2';
$lang['address_handling'] = 'Address Handling';
$lang['add_msg_template'] = 'Dodaj nowy szablon wiadomości';
$lang['admin_email_addresses'] = 'Comma seperated list of admin email addresses to use when a new order is submitted';
$lang['admin_email_template'] = 'Szablon emaila administratora';
$lang['amount'] = 'Ilość';
$lang['amt_due'] = 'Amt. Due';
$lang['any'] = 'Any';
$lang['ask_delete'] = 'Napewno skasować tą pozycję?';
$lang['ask_delete_order'] = 'Napewno skasować to zam&oacute;wienie?  Kasowanie zam&oacute;wień nie jest zalecane.';
$lang['ask_delete_payment'] = 'Are you sure you want to permanently remove all records of this payment?';
$lang['ask_edit_billing'] = 'Are you sure you want to modify the billing information for this order as specified above?';
$lang['ask_manual_payment'] = 'Are you sure you want to process a manual payment to the credit card for this amount?';
$lang['ask_saveprefs'] = 'Are you sure you want to adjust the preferences of this module?\nUse caution, incorrect adjustments may break a working website.';
$lang['ask_setorderstatus'] = 'A possible order status change has been detected, would you like to set the status to: ';
$lang['back'] = 'Powr&oacute;t';
$lang['back_to_orders'] = 'Powr&oacute;t do zam&oacute;wień';
$lang['backorder'] = 'Back Ordered';
$lang['balancedue'] = 'Balance Due (partially paid)';
$lang['bill_to'] = 'Rachunek dla';
$lang['billing'] = 'Rachunek ';
$lang['billing_address'] = 'Rachunek  adres';
$lang['billing_form_templates'] = 'Billing Form Templates';
$lang['billing_info'] = 'Billing Information';
$lang['body'] = 'Treść wiadomości';
$lang['cancel'] = 'Anuluj';
$lang['cancelled'] = 'Anulowane';
$lang['captcha_title'] = 'Tekst captcha ';
$lang['cart_module'] = 'Moduł koszyka';
$lang['cart_settings'] = 'Ustawienia koszyka';
$lang['cash'] = 'Got&oacute;wka';
$lang['cc_AMEX'] = 'American Express';
$lang['cc_Discover'] = 'Discover';
$lang['cc_MasterCard'] = 'Mastercard';
$lang['cc_Visa'] = 'Visa';
$lang['city'] = 'City';
$lang['company'] = 'Company';
$lang['completed'] = 'Completed';
$lang['completion_templates'] = 'Completion Templates';
$lang['confirmed'] = 'Potwierdzone';
$lang['confirm_order'] = 'Potwierdź swoje zam&oacute;wienie';
$lang['confirmation_form_templates'] = 'Confirmation Form Templates';
$lang['confirmation_num'] = 'Confirmation Number';
$lang['cookie'] = 'Use address stored in a cookie';
$lang['country'] = 'Kraj';
$lang['coupon_code'] = 'Kod kuponu';
$lang['created'] = 'Utworzone';
$lang['created_by'] = 'Utworzone przez';
$lang['create_invoice'] = 'Create Invoice for this order';
$lang['create_invoice_for'] = 'Create Invoice for order %s';
$lang['creditcard'] = 'Credit Card';
$lang['creditcard_expiry'] = 'CreditCard Expiry Date';
$lang['creditcard_number'] = 'CreditCard Number';
$lang['creditcard_type'] = 'CreditCard Type';
$lang['creditcard_verifycode'] = 'CCV Code';
$lang['customer_name'] = 'Customer Name';
$lang['date'] = 'Date';
$lang['date_range'] = 'Date Range';
$lang['dateopt_exactdates'] = 'Exact Dates';
$lang['dateopt_7days'] = 'Last 7 Days';
$lang['dateopt_14days'] = 'Last 14 Days';
$lang['dateopt_30days'] = 'Last 30 Days';
$lang['dateopt_3months'] = 'Last 3 Months';
$lang['dateopt_6months'] = 'Last 6 Months';
$lang['dateopt_1year'] = 'Last Year';
$lang['default_templates'] = 'Default Templates';
$lang['delete'] = 'Skasuj';
$lang['delivered'] = 'Dostarczone';
$lang['description'] = 'Opis';
$lang['desc_order_by'] = 'Zam&oacute;wione przez {$billing->get_firstname()} {$billing->get_lastname()}';
$lang['destinations'] = 'Destinations';
$lang['details'] = 'Szczeg&oacute;ły';
$lang['dflt_billingform_template'] = 'Default Billing Form Template';
$lang['dflt_confirmorder_template'] = 'Default Confirm Order Form Template';
$lang['dflt_completion_template'] = 'Default Completion Template';
$lang['dflt_gateway_complete_template'] = 'Default &quot;Gateway Transaction Complete&quot; Template';
$lang['dflt_invoice_message'] = 'Thank you for shopping with {sitename}.';
$lang['dflt_invoice_template'] = 'Default Invoice Template';
$lang['dflt_paymentform_template'] = 'Default Payment Form Template';
$lang['discount'] = 'Discount';
$lang['edit'] = 'Edytuj';
$lang['edit_billing_info'] = 'Edytuj informacje o rachunku';
$lang['edit_report_template'] = 'Editing Template for Report: %s';
$lang['end_date'] = 'End Date';
$lang['email'] = 'Email';
$lang['email_address'] = 'Email Address';
$lang['email_invoice'] = 'Email this invoice to the customer and authorized admins';
$lang['email_sent_to'] = 'Email Sent to';
$lang['email_subject'] = 'Email Subject';
$lang['error_badcaptcha'] = 'The captcha value supplied was incorrect';
$lang['error_creditcard_expired'] = 'This credit card is expired';
$lang['error_encryption_problem'] = 'A problem occurred encrypting or decrypting data';
$lang['error_gateway_invalid_data'] = 'Could not confirm data validity from payment gateway module';
$lang['error_insufficientparams'] = 'A required parameter was missing';
$lang['error_invalid_address'] = 'The address you specified for &quot;%s&quot; is invalid.  Please ensure that all required fields are completed.';
$lang['error_invalidfield'] = 'The following field is invalid: %s';
$lang['error_invalidgateway'] = 'The selected gateway module is invalid for this purpose';
$lang['error_missingshippinginfo'] = 'Insufficient shipping information supplied';
$lang['error_namexists'] = 'An item with that name already exists';
$lang['error_nocartmodule'] = 'Could not find a Cart module.  Please make sure that a cart module is installed, and selected in the Products module preferences.';
$lang['error_noemailaddress'] = 'No email address has been associated with this userid';
$lang['error_nofeumodule'] = 'Could not find the FrontEndUsers module';
$lang['error_nopaymentgateway'] = 'No payment gateway specified';
$lang['error_noproductsmodule'] = 'Could not find the Products module';
$lang['error_norequiredgroup'] = 'Please set a required membership group in the preferences tab';
$lang['error_notloggedin'] = 'The user is not logged in <em>(or not a member of the required group)</em>';
$lang['error_orderinvalid'] = 'There is a problem with this order (the information is inconsistent)';
$lang['error_ordernotfound'] = 'The requested order could not be found';
$lang['error_orderprocessing'] = 'An error occurred while processing this order (soft fail)';
$lang['error_paymentnotfound'] = 'The specified payment could not be found';
$lang['error_possible_hack'] = 'Detected a possible hack: your uid (%s) does not match the uid (%s) found for order %s.  Please contact your system administrator.';
$lang['error_requiressl'] = 'The gateway selected for use on this site requires a secure connection, which is not established yet';
$lang['error_retrieve_data'] = 'A problem occurred when trying to retrieve pertinent information from the database';
$lang['error_save'] = 'Error Saving a data item: %s';
$lang['error_security_key'] = 'The encryption key for this transaction could not be retrieved';
$lang['error_paymentgateway_incompatible'] = 'The selected payment gateway is incompatible with this order processing module.  Please contact the site administrator';
$lang['error_permissiondenied'] = 'Permission Denied';
$lang['error_unknownstatus'] = 'Received an unknown status from the payment gateway';
$lang['error_usernotingroup'] = 'The currently logged in user is not a member of the required group';
$lang['fax'] = 'Fax';
$lang['filter'] = 'Filter';
$lang['first_name'] = 'First Name';
$lang['firstpage'] = '<<';
$lang['friendlyname'] = 'Order Manager';
$lang['from'] = 'From';
$lang['gateway'] = 'Gateway';
$lang['gateway_module'] = 'Payment Gateway Module';
$lang['gateway_complete_templates'] = 'Gateway Complete Templates';
$lang['gateway_failure_message'] = 'Your transaction was not completed.  Either the operation was cancelled or some other error occurred.  Please confirm your payment information and try again.  Your cart has been emptied for your safety and convenience.  Thank you for your time';
$lang['general_settings'] = 'Ustawienia';
$lang['get_address_from_feu'] = 'Użyj profilu użytkownika';
$lang['help_param_nocaptcha'] = 'If this parameter is set, captcha will be turned off';
$lang['help_param_template'] = 'Specify a non default template to use for the default action';
$lang['hold'] = 'Hold';
$lang['html'] = 'HTML';
$lang['html_email'] = 'Send Email in HTML Format';
$lang['id'] = 'Id';
$lang['incomplete'] = 'Incomplete (partially shipped)';
$lang['info_admin_invoice_template'] = 'Select a template that will be used for the printable invoice popup display when managing an order';
$lang['info_adminemail_template'] = 'This template controls the layout and content of the email that is sent to the authorized administrator when a new order is submitted';
$lang['info_allow_anon_checkout'] = 'If disabled, users will be required to have a valid FEU login to be able to check out';
$lang['info_allow_creditcard_entry'] = 'Some payment gateways require the user to enter credit card information on your site before submitting that information to the payment processing engine.  Credit Card information will be temporarily stored in an encrypted format until processing is complete or cancelled.  Periodic cleaning of the temporary information will ensure that this information is not retained on your server, unless you enable the option to store credit card information <em>(not recommended)</em>';
$lang['info_billingpage'] = '<strong>Note:</strong> This preference, and the others like it are used to allow the administrator to use different CMSMS pages for the different forms.  If &quot;none&quot; is specified, then the current page will be used.';
$lang['info_ccprocessing_module'] = 'This module is used for manual credit card processing';
$lang['info_coupon_code'] = 'Enter a coupon code for a possible discount';
$lang['info_default_templates'] = 'This form controls the content of the template when you click &#039;New Template&#039; in the &#039;Confirmation Form Templates&#039; tab.  Editing the text here will have no immediate effect on the appearance of your site';
$lang['info_edit_report_template'] = 'These templates determine the style and layout for a particular report';
$lang['info_encryption_key'] = 'This key is randomly generated when the module is installed.  Use caution when changing this value if there are already orders in the system.';
$lang['info_forcessl'] = '<strong>Note: Recommended</strong>.  If you are allowing customers to enter credit card information, you should enable this option and ensure that you have properly configured your site for SSL access to ensure that the transmission of credit card information is done over an encrypted connection.';
$lang['info_gateway_description'] = 'This information is sent to the payment gateway for each transaction, and may be used for information such as the name that shows up to clients on their credit card statements. This is a smarty template, allowing customization of the display.';
$lang['info_incomplete_timeout'] = 'Proposed orders that have had no activity in a set number of minutes can be set to incomplete automatically.  Set the value to 0 to disable this functionality';
$lang['info_invoicepage'] = '<strong>Note:</strong> This page is also used as the success and failure page for payment gateways';
$lang['inform_no_cc_processing'] = 'Are you aware that you are merely editing existing payment information?\nNo new credit card transaction will be processed.';
$lang['info_order_notes'] = 'Supply some special notes for this order';
$lang['info_require_membergroup'] = 'This setting only applies if NOT allowing anonymous users to perform checkout';
$lang['info_skip_invoice_page'] = 'When allowing users to specify payment information,<br/>should they then procede to the invoice page,<br/>or directly to the transaction completion page?';
$lang['info_store_creditcard_data'] = '<strong>Note: <span style=&quot;color: red;&quot;>Not Recommended</span></strong> This information is stored in the database.  Although encryption is used to store private data it cannot be considered to be secure.  It is recommended that this option never be used.  Instead, please use a compatible payment gateway module.';
$lang['info_useremail_template'] = 'This template controls the layout and content of the email that is sent to the user when a new order is submitted';
$lang['info_validcountries'] = 'Specify a list of country codes and country names (one entry per line) for the countries that will show up in the address list.  i.e: US=United States.  If no value is specified, the default country list will be used.';
$lang['info_validstates'] = 'Specify a list of state codes and names (one entry per line) for the states or provinces that will show up in the address list.  i.e: AB=Alberta.  If no value is specified, the default state list will be used.';
$lang['info_use_integer'] = 'Use only integer values';
$lang['interval_oneday'] = 'One Day';
$lang['interval_onemonth'] = 'One Month';
$lang['interval_onequarter'] = 'One Quarter';
$lang['interval_oneweek'] = 'One Week';
$lang['interval_oneyear'] = 'One Year';
$lang['interval_twoweeks'] = 'Two Weeks';
$lang['invoice'] = 'Invoice';
$lang['invoiced'] = 'Invoiced';
$lang['invoice_settings'] = 'Invoice Settings';
$lang['invoice_templates'] = 'Invoice Templates';
$lang['items'] = 'Items';
$lang['last_name'] = 'Last Name';
$lang['last_modified'] = 'Last Modified';
$lang['lastpage'] = '>>';
$lang['lbl_back'] = 'Back';
$lang['lbl_preferences'] = 'Preferences';
$lang['lbl_templates'] = 'Templates';
$lang['legend_dates'] = 'Select Dates';
$lang['legend_reports'] = 'Reports';
$lang['message'] = 'Message';
$lang['message_templates'] = 'Message Templates';
$lang['method'] = 'Method';
$lang['moddescription'] = 'A simple order processing module';
$lang['modified'] = 'Modified';
$lang['msg_async_transaction'] = 'Handled Async Transaction %s for order %s';
$lang['msg_order_cancelled'] = 'Order %s cancelled or declined';
$lang['msg_order_error'] = 'Error encountered for order %s';
$lang['msg_order_payment'] = 'Payment received for order %s.';
$lang['msg_order_pending'] = 'Order status changed to &quot;Pending&quot; on %s';
$lang['msg_payment_cancelled'] = 'Payment %s was cancelled for order %s';
$lang['msg_payment_declined'] = 'Payment %s was declined for order %s';
$lang['msg_payment_error'] = 'An error occurred on payment %s for order %s';
$lang['msg_payment_received'] = 'Payment %s (%s) was received for order %s';
$lang['msg_payment_removed'] = 'Payment removed from the order';
$lang['msg_payment_setbackwards'] = 'Attempted to set status of order %s backwards from PAID to PENDING';
$lang['name'] = 'Name';
$lang['net'] = 'Net';
$lang['net_price'] = 'Net Price';
$lang['new_order_submitted'] = 'A new order has been submitted';
$lang['next'] = 'Następny';
$lang['nextpage'] = '>';
$lang['no'] = 'Nie';
$lang['no_items_in_cart'] = 'There are no items in your cart.  Please add some before trying to checkout.';
$lang['no_report_data'] = 'No matching data found';
$lang['none'] = 'Żaden';
$lang['notcancelledshipped'] = 'Any but Cancelled or Shipped';
$lang['notes'] = 'Notes';
$lang['notshipped'] = 'Nie dostarczony';
$lang['num'] = 'Nr';
$lang['online'] = 'on-line';
$lang['order'] = 'Zam&oacute;wienie';
$lang['orders'] = 'Zam&oacute;wienia';
$lang['order_confirm_form_templates'] = 'Confirm Order Templates';
$lang['order_details'] = 'Szczeg&oacute;ły zam&oacute;wienia';
$lang['order_notes'] = 'Order Notes';
$lang['order_number'] = 'Faktura';
$lang['order_processing'] = 'Order Processing';
$lang['order_statistics'] = 'Order Statistics';
$lang['order_summary'] = 'Order Summary';
$lang['ORDERS_ITEMTYPE_DISCOUNT'] = 'Discount';
$lang['paid'] = 'Zapłacone';
$lang['payment_amount'] = 'Amount of Payment';
$lang['payment_approved'] = 'Zatwierdzone';
$lang['payment_cancelled'] = 'Anulowane';
$lang['payment_date'] = 'Data płatności';
$lang['payment_declined'] = 'Declined';
$lang['payment_error'] = 'Błąd';
$lang['payment_form_templates'] = 'Payment Form Templates';
$lang['payment_gateway_settings'] = 'Payment Gateway Settings';
$lang['payment_history'] = 'Payment History';
$lang['payment_info'] = 'Payment Information';
$lang['payment_method'] = 'Payment Method';
$lang['payment_notprocessed'] = 'Not Processed';
$lang['payment_options'] = 'Payment Options';
$lang['payment_other'] = 'Other';
$lang['payment_pending'] = 'Pending';
$lang['payment_status'] = 'Payment Status';
$lang['pending'] = 'Pending';
$lang['phone'] = 'Telefon';
$lang['popup_new_window'] = 'Popup invoice in new window';
$lang['postinstall'] = 'The orders module has been successfully installed';
$lang['postuninstall'] = 'The orders module and all associated data has been removed';
$lang['post_order_msg'] = 'Post Order Message';
$lang['postal'] = 'Zip/Postal Code';
$lang['preferences'] = 'Preferences';
$lang['prevpage'] = '<';
$lang['price'] = 'Cena';
$lang['print_invoice'] = 'Wydrukuj fakturę';
$lang['procede_manual_checkout'] = 'Procede with Manual Checkout';
$lang['process_manual_payment'] = 'Process Manual Payment';
$lang['process_new_transaction'] = 'Process CreditCard Transaction through Gateway';
$lang['process_order'] = 'Process Order';
$lang['product_id'] = 'Product ID';
$lang['promotions_module'] = 'Promotions Module';
$lang['promotions_settings'] = 'Promotions Settings';
$lang['prompt_address_property_map'] = 'Address to FEU Property Map';
$lang['prompt_address_retrieval'] = 'Address Retrieval Method';
$lang['prompt_admin_invoice_template'] = 'Printable Invoice Template';
$lang['prompt_allow_anon_checkout'] = 'Allow anonymous users to checkout';
$lang['prompt_allow_creditcard_entry'] = 'Allow customer to enter credit card information';
$lang['prompt_billingpage'] = 'Page to assume that the billing form will be displayed on.  This is usually the page with your <code>{Orders}</code> tag.';
$lang['prompt_ccprocessing_module'] = 'Credit Card Processing Gateway';
$lang['prompt_confirmpage'] = 'Page to use for the confirmation form';
$lang['prompt_datastore_timeout'] = 'Expiry period for temporary transaction information';
$lang['prompt_date_search_type'] = 'Filter Records that were ';
$lang['prompt_dflt_country'] = 'Default Country';
$lang['prompt_dflt_state'] = 'Default State';
$lang['prompt_email'] = 'Email Address';
$lang['prompt_encryption_key'] = 'Encryption Key';
$lang['prompt_forcessl'] = 'Redirect the page to HTTPS for input of payment info';
$lang['prompt_gateway_description'] = 'Description to send to the payment gateway';
$lang['prompt_incomplete_timeout'] = 'Automatically set orders to incomplete <em>(if proposed)</em> after N minutes';
$lang['prompt_invoice_message'] = 'Message to appear at the top of all invoices';
$lang['prompt_invoicepage'] = 'Page to use for the invoice display';
$lang['prompt_of'] = 'Of';
$lang['prompt_ordernum_prefix'] = 'OrderNum Prefix';
$lang['prompt_page'] = 'Page';
$lang['prompt_pagelimit'] = 'Number of Orders per page';
$lang['prompt_paymentpage'] = 'Page to use for the payment form';
$lang['prompt_permit_deletion'] = 'Allow deletion of orders';
$lang['prompt_requirepostal'] = 'Postal/Zip code is a required field on the billing form';
$lang['prompt_requirestate'] = 'State/Province is a required field in the billing form';
$lang['prompt_skip_invoice_page'] = 'Skip Invoice Page';
$lang['prompt_store_creditcard_data'] = 'Permanently Store CreditCard Information';
$lang['prompt_template'] = 'Message Template';
$lang['prompt_username'] = 'Username';
$lang['prompt_validcountries'] = 'Valid Countries:';
$lang['prompt_validstates'] = 'Valid States:';
$lang['proposed'] = 'Proposed';
$lang['quantity'] = 'Quantity';
$lang['really_uninstall'] = 'Are you sure you really want to do this? Any data associated with this module will be lost if you procede';
$lang['records_matching_query'] = 'Number of records matching your query';
$lang['regex'] = 'Regular Expression';
$lang['remember_last_address_used'] = 'Use the address from the last order';
$lang['report'] = 'Raport';
$lang['reports'] = 'Raporty';
$lang['report_recent_payments'] = 'Recent Payments';
$lang['report_shipping_costs'] = 'Shipping Costs';
$lang['report_subscr_picklist'] = 'Subscription Picklist';
$lang['report_templates'] = 'Report Templates';
$lang['return'] = 'Return';
$lang['require_group_membership'] = 'Require that all users that procede to the order stage be a member in this FEU Group';
$lang['security_settings'] = 'Security Settings';
$lang['select_action'] = 'Select Action';
$lang['select_one'] = 'Select One';
$lang['select_invoice_template'] = 'Select Invoice Template';
$lang['send'] = 'Send';
$lang['send_message'] = 'Send This Customer A Message';
$lang['sent'] = 'Sent';
$lang['ship_to'] = 'Ship To';
$lang['shipped'] = 'Shipped';
$lang['shipping'] = 'Shipping';
$lang['shipping_address'] = 'Shipping Address';
$lang['shipping_costs'] = 'Shipping Costs';
$lang['shipping_info'] = 'Shipping Information';
$lang['shipping_info_for'] = 'Shipping Address For';
$lang['shipping_info_if_different'] = 'Shipping Information <em>(If different from billing information)</em>';
$lang['shipping_message'] = 'Message related to this destination';
$lang['shipping_module'] = 'Shipping Module';
$lang['shipping_settings'] = 'Shipping Settings';
$lang['shipping_total'] = 'Shipping Total';
$lang['sku'] = 'SKU';
$lang['source'] = 'Source';
$lang['special_instructions'] = 'Special Instructions';
$lang['start_date'] = 'Start Date';
$lang['state/province'] = 'State/Province';
$lang['status'] = 'Status';
$lang['subscription'] = 'Subscription';
$lang['subject'] = 'Subject';
$lang['submit'] = 'Submit';
$lang['submitted'] = 'Submitted';
$lang['submit_payment_info'] = 'Submit Payment Info';
$lang['subscribed'] = 'Subscribed';
$lang['subtotal'] = 'Subtotal';
$lang['tax'] = 'Tax';
$lang['tax_module'] = 'Tax Module';
$lang['tax_settings'] = 'Tax Settings';
$lang['template'] = 'Template';
$lang['template_name'] = 'Template Name';
$lang['thank_you_for_order'] = 'Thank you for your purchase from {sitename}';
$lang['timeout'] = 'Timed out';
$lang['title_adminemail_template'] = 'Administrator Email Template';
$lang['title_first_page'] = 'Go to the first page';
$lang['title_last_page'] = 'Go to the last page';
$lang['title_manage_order'] = 'Manage Order';
$lang['title_manual_process'] = 'Manual Transaction Processing';
$lang['title_next_page'] = 'Go to the next page';
$lang['title_prev_page'] = 'Go to the previous page';
$lang['title_useremail_template'] = 'User Email Template';
$lang['to'] = 'To';
$lang['total'] = 'Total';
$lang['tracking_num'] = 'Tracking Number';
$lang['transaction_id'] = 'Transaction Id';
$lang['transaction_successful'] = 'Payment processed successfully';
$lang['type'] = 'Type';
$lang['update_status'] = 'Update Status';
$lang['unit_price'] = 'Unit Price';
$lang['unit_weight'] = 'Unit Weight';
$lang['unknown'] = 'Unknown';
$lang['unlimited'] = 'Unlimited';
$lang['username'] = 'Username';
$lang['user_email_template'] = 'User Email Template';
$lang['view'] = 'Zobacz';
$lang['view_message'] = 'Zobacz wiadomość';
$lang['view_messages'] = 'Zobacz wiadomość odnośnie tego zam&oacute;wienia';
$lang['warning_https'] = '<strong>Warning!</strong> You are not using a secure (https) connection.  It is not recommended that you continue with this action without a secure connection.';
$lang['warning_manual_process'] = '<strong>Warning!</strong> This screen allows manual processing of credit card transactions using an online gateway.  Use caution!';
$lang['warning_orderstatus_paid'] = '<strong>Warning!</strong> This order has already been paid.  You should not be processing a manual payment on this order';
$lang['warning_orderstatus_cancelled'] = '<strong>Warning!</strong> This order has been cancelled.  You should not be processing a manual payment on this order';
$lang['warning_no_ccprocessing_gateway'] = '<strong>Warning!</strong> Although you may enter credit card information for a new or existing payment, no online processing will occur.';
$lang['warning_order_paid_in_full'] = '<strong>Warning!</strong> This order already appears to have been paid in full.';
$lang['weight'] = 'Waga';
$lang['within'] = 'Within';
$lang['yes'] = 'Tak';
$lang['utma'] = '156861353.130117701.1281030249.1283951162.1284039329.12';
$lang['utmz'] = '156861353.1284039329.12.8.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/project/files/413|utmcmd=referral';
$lang['qca'] = 'P0-1706049120-1281030249820';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>
